@@ -1,17 +1,26 @@
 package Sah::Schema::filename;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-08-08'; # DATE
+our $DATE = '2020-08-26'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem file name',
+    min_len => 1,
+
     'x.completion' => ['filename'],
     prefilters => [
         'Path::expand_tilde_when_on_unix',
         'Path::strip_slashes_when_on_unix',
     ],
+
+    examples => [
+        {value=>'', valid=>0},
+        {value=>'foo', valid=>1},
+        {value=>'foo/bar', valid=>1},
+    ],
+
 }, {}];
 
 1;
@@ -29,7 +38,7 @@ Sah::Schema::filename - Filesystem file name
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::filename (from Perl distribution Sah-Schemas-Path), released on 2020-08-08.
+This document describes version 0.015 of Sah::Schema::filename (from Perl distribution Sah-Schemas-Path), released on 2020-08-26.
 
 =head1 SYNOPSIS
 
@@ -92,6 +101,14 @@ L<Perinci::CmdLine> to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+Sample data:
+
+ ""  # INVALID
+
+ "foo"  # valid
+
+ "foo/bar"  # valid
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Path>.
